﻿* Encoding: UTF-8.

************************************************************************************************************************
*** SINTAXIS DE TABULADOS MÓDULO AMBIENTAL DE HOGARES - ENEMDU 2022.
*** Realizado por: Ramiro Benavides - Dirección de Estadísticas Agropecuarias y Ambientales.
*** Fecha: 25 de noviembre de 2022.
*************************************************************************************************************************
* A.  Cargar la base del Módulo Ambiental en Hogares ENEMDU (edición Agosto 2022) e inicialización de variables de desglose.

GET
  FILE='C:\Users\Lenovo\Documents\HOGARES 2022\BDD Publicadas\BDD_ENEMDU_2022_08\enemdu_ambiental_2022_08.sav'. 
DATASET NAME Ambientales WINDOW=FRONT. /* Esta base tiene 8962 registros.

DATASET ACTIVATE Ambientales.

COMPUTE NACIONAL=1.
VARIABLE LABELS NACIONAL "NACIONAL".
VALUE LABELS NACIONAL 1"Nacional".

COMPUTE prov = TRUNC(ciudad/10000).

VALUE LABELS prov 1'Azuay'
2'Bolívar'
3'Cañar'
4'Carchi'
5'Cotopaxi'
6'Chimborazo'
7'El Oro'
8'Esmeraldas'
9'Guayas'
10'Imbabura'
11'Loja'
12'Los Ríos'
13'Manabí'
14'Morona-Santiago'
15'Napo'
16'Pastaza'
17'Pichincha'
18'Tungurahua'
19'Zamora-Chinchipe'
20'Galápagos'
21'Sucumbíos'
22'Orellana'
23'Sto. Dgo de los Tsáchilas'
24'Santa Elena'
90'Zona No Delimitada'.

FREQUENCIES prov.

RECODE prov (1 thru 6, 10, 11, 17, 18 = 1) (7, 8, 9, 12, 13, 23, 24, 90 = 2) (14, 15, 16, 19, 21, 22 = 3) (20 = 4) INTO REG_NATURAL.
VARIABLE LABELS REG_NATURAL "Región Natural - DEAGA".
VALUE LABELS REG_NATURAL 1'Sierra' 2'Costa' 3'Amazonía' 4'Región Insular'.
FREQUENCIES REG_NATURAL.

DATASET ACTIVATE Ambientales.
SORT CASES BY id_hogar (A).

**********************************************************************************************************************************
**********************************************************************************************************************************
* B.  Fusión de la base del Módulo Ambiental en Hogares ENEMDU (edición Agosto 2022) con la base de
* Vivienda_Hogar ENEMDU (edición Agosto 2022).
* Básicamente, se traen de la base de Vivienda las variables:
* s12p9 = vi12 ("¿Con qué tipo de alumbrado cuenta principalmente este hogar?"),
* vi10 ("¿De dónde obtiene el agua?"),
* s12p16c = vi10a ("¿El agua que recibe la vivienda es?").

GET
  FILE='C:\Users\Lenovo\Documents\HOGARES 2022\BDD Publicadas\BDD_ENEMDU_2022_08\enemdu_vivienda_hogar_2022_08.sav'. 
DATASET NAME Vivienda WINDOW=FRONT. /* Esta base tiene 8962 registros.

SORT CASES BY id_hogar (A).

DATASET ACTIVATE Ambientales.
MATCH FILES /FILE=*
  /FILE='Vivienda'
  /RENAME (area ciudad conglomerado estrato fexp hogar id_vivienda panelm periodo upm vivienda vi01 
    vi02 vi03a vi03b vi04a vi04b vi05a vi05b vi06 vi07 vi07a vi07b vi08 vi09 vi09a vi09b vi101 vi102 
    vi11 vi13 vi14 vi141 vi142 vi143 vi144 vi1511 vi1521 vi1512 vi1522 vi1531 vi1541 vi1532 vi1542 
    vi1533 vi1543 vi1534 vi1544 vi1535 vi1545 vi1536 vi1546 = d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 
    d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 
    d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51) 
  /IN source01
  /BY id_hogar
  /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 
    d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 
    d50 d51.
VARIABLE LABELS source01 'Case source is Vivienda'.
EXECUTE.

DATASET CLOSE Vivienda.

**********************************************************************************************************************************
**********************************************************************************************************************************.
* C. Cálculo de los tabulados.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe de Hogar o Cónyuge)
* --- TABLA 1. HOGARES QUE CLASIFICARON AL MENOS UN RESIDUO.

WEIGHT OFF.

FREQUENCIES s101p11 s101p12a s101p12b s101p12c s101p12d s101p12e.
COMPUTE P1 = MIN (s101p11, s101p12a, s101p12b, s101p12c, s101p12d, s101p12e).
VARIABLE LABELS P1 "Hogares que clasificaron al menos un residuo".
VALUE LABELS P1 2'No' 1'Sí'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA P1 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY P1
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=P1 EMPTY=INCLUDE.

DELETE VARIABLES P1.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe de Hogar o Cónyuge)
* --- TABLA 2. HOGARES QUE CLASIFICAN SEGÚN EL TIPO DE RESIDUO.
* --- 2.1 Clasificó residuos orgánicos.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p11 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY s101p11
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p11 EMPTY=INCLUDE.

* --- 2.2 Clasificó residuos inorgánicos: Papel, cartón.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA  s101p12a DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY s101p12a
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p12a EMPTY=INCLUDE.

* --- 2.3 Clasificó residuos inorgánicos: Plástico.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p12b DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY s101p12b
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p12b EMPTY=INCLUDE.

* --- 2.4 Clasificó residuos inorgánicos: Vidrio.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p12c DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY s101p12c
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p12c EMPTY=INCLUDE.

* --- 2.5 Clasificó residuos inorgánicos: Metal.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p12d DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY s101p12d
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p12d EMPTY=INCLUDE.

* --- 2.6 Clasificó residuos inorgánicos: Tetrapak.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p12e DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY s101p12e
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p12e EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 3. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES CÓMO ELIMINÓ LOS RESIDUOS DE ORGÁNICOS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p2a DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s101p2a [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p2a ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 4. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES, CÓMO ELIMINÓ LOS RESIDUOS DE PAPEL, CARTÓN.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p2b DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s101p2b [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p2b ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 5. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES, CÓMO ELIMINÓ LOS RESIDUOS DE PLÁSTICO.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p2c DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s101p2c [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p2c ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 6. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES,CÓMO ELIMINÓ LOS RESIDUOS DE VIDRIO.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p2d DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s101p2d [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p2d ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 7. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES, CÓMO ELIMINÓ LOS RESIDUOS DE METAL.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p2e DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s101p2e [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p2e ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 8. PRINCIPALMENTE, EN SU HOGAR DURANTE LOS ÚLTIMOS 12 MESES, CÓMO ELIMINÓ LOS RESIDUOS DE TETRAPAK.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s101p2f DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s101p2f [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s101p2f ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 9.  DISPOSICIÓN FINAL DE LAS PILAS.

WEIGHT OFF.

COMPUTE s101p5a_temp = s101p5a.
RECODE s101p5a_temp (8=SYSMIS).
VARIABLE LABELS s101p5a_temp "Disposición final de las pilas".
VALUE LABELS s101p5a_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p5a_temp DISPLAY=LABEL
  /TABLE s101p5a_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p5a_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p5a_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 10.  DISPOSICIÓN FINAL DE LOS DESECHOS FARMACÉUTICOS (MEDICAMENTOS).

WEIGHT OFF.

COMPUTE s101p5b_temp = s101p5b.
RECODE s101p5b_temp (8=SYSMIS).
VARIABLE LABELS s101p5b_temp "Disposición final de los desechos farmaceúticos (medicamentos)".
VALUE LABELS s101p5b_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p5b_temp DISPLAY=LABEL
  /TABLE s101p5b_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p5b_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p5b_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 11.  DISPOSICIÓN FINAL DE ACEITE Y/O GRASAS (COCINA).

WEIGHT OFF.

COMPUTE s101p5c_temp = s101p5c.
RECODE s101p5c_temp (8=SYSMIS) (ELSE = COPY).
VARIABLE LABELS s101p5c_temp "Disposición final de aceite y/o grasas (cocina)".
VALUE LABELS s101p5c_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p5c_temp DISPLAY=LABEL
  /TABLE s101p5c_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p5c_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p5c_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 12.  DISPOSICIÓN FINAL UTILIZADA POR LOS HOGARES PARA LOS FOCOS AHORRADORES.

WEIGHT OFF.

COMPUTE filtro_electricidad = (vi12 <= 2).

COMPUTE s101p5d_temp = s101p5d.
RECODE s101p5d_temp (6, 8=SYSMIS).
VARIABLE LABELS s101p5d_temp "Disposición final de los focos ahorradores".
VALUE LABELS s101p5d_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=s101p5d_temp NACIONAL filtro_electricidad DISPLAY=LABEL
  /TABLE s101p5d_temp [C][COUNT F40.0, COLPCT.COUNT PCT40.1] BY NACIONAL [C] > filtro_electricidad
  /CATEGORIES VARIABLES=s101p5d_temp ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=filtro_electricidad[1] EMPTY=EXCLUDE.

DELETE VARIABLES s101p5d_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 13.  DISPOSICIÓN FINAL DE DESECHOS ENVASES DE INSECTICIDAS / PRODUCTOS DE LIMPIEZA DEL HOGAR.

WEIGHT OFF.

COMPUTE s101p5e_temp = s101p5e.
RECODE s101p5e_temp (8 =SYSMIS).
VARIABLE LABELS s101p5e_temp "Disposición final de desechos envases de insecticidas / productos de limpieza del hogar".
VALUE LABELS s101p5e_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p5e_temp DISPLAY=LABEL
  /TABLE s101p5e_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p5e_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p5e_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 14.  DISPOSICIÓN FINAL DE DESECHOS CARTUCHOS Y TÓNERS.

WEIGHT OFF.

COMPUTE s101p5f_temp = s101p5f.
RECODE s101p5f_temp (8=SYSMIS).
VARIABLE LABELS s101p5f_temp "Disposición final de cartuchos y tóners".
VALUE LABELS s101p5f_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p5f_temp DISPLAY=LABEL
  /TABLE s101p5f_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p5f_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p5f_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 15.  DISPOSICIÓN FINAL DE FOCOS LED.

WEIGHT OFF.

COMPUTE s101p5g_temp = s101p5g.
RECODE s101p5g_temp (8=SYSMIS).
VARIABLE LABELS s101p5g_temp "Disposición final de cartuchos y tóners".
VALUE LABELS s101p5g_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Regaló (escuela,vecina..), vendió'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Preparó compost ABONO o utilizó como alimento para animales'
6'Almacenó en su hogar'
7'Entregó a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=s101p5g_temp NACIONAL filtro_electricidad DISPLAY=LABEL
  /TABLE s101p5g_temp [C][COUNT F40.0, COLPCT.COUNT PCT40.1] BY NACIONAL [C] > filtro_electricidad
  /CATEGORIES VARIABLES=s101p5g_temp ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=filtro_electricidad[1] EMPTY=EXCLUDE.

DELETE VARIABLES s101p5g_temp filtro_electricidad.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge) (SECCIÓN NUEVA SOBRE DESECHOS ELÉCTRICOS/ELECTRÓNICOS)
* --- TABLA 16.A.  DISPOSICIÓN FINAL DE COMPUTADORA DE ESCRITORIO.

WEIGHT OFF.

COMPUTE s101p51a_temp = s101p51a.
RECODE s101p51a_temp (7=SYSMIS).
VARIABLE LABELS s101p51a_temp "Disposición final de computadora de escritorio".
VALUE LABELS s101p51a_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51a_temp DISPLAY=LABEL
  /TABLE s101p51a_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51a_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51a_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.B.  DISPOSICIÓN FINAL DE COMPUTADORA LAPTOP / TABLET.

WEIGHT OFF.

COMPUTE s101p51b_temp = s101p51b.
RECODE s101p51b_temp (7=SYSMIS).
VARIABLE LABELS s101p51b_temp "Disposición final de computadora Laptop / Tablet".
VALUE LABELS s101p51b_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51b_temp DISPLAY=LABEL
  /TABLE s101p51b_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51b_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51b_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.C.  DISPOSICIÓN FINAL DE TELEVISOR A COLOR.

WEIGHT OFF.

COMPUTE s101p51c_temp = s101p51c.
RECODE s101p51c_temp (7=SYSMIS).
VARIABLE LABELS s101p51c_temp "Disposición final de televisión a color".
VALUE LABELS s101p51c_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51c_temp DISPLAY=LABEL
  /TABLE s101p51c_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51c_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51c_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.D.  DISPOSICIÓN FINAL DE REFRIGERADOR.

WEIGHT OFF.

COMPUTE s101p51d_temp = s101p51d.
RECODE s101p51d_temp (7=SYSMIS).
VARIABLE LABELS s101p51d_temp "Disposición final del refrigerador".
VALUE LABELS s101p51d_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51d_temp DISPLAY=LABEL
  /TABLE s101p51d_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51d_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51d_temp.

-------------------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.E.  DISPOSICIÓN FINAL DE LAVADORA DE ROPA.

WEIGHT OFF.

COMPUTE s101p51e_temp = s101p51e.
RECODE s101p51e_temp (7=SYSMIS).
VARIABLE LABELS s101p51e_temp "Disposición final de lavadora de ropa".
VALUE LABELS s101p51e_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51e_temp DISPLAY=LABEL
  /TABLE s101p51e_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51e_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51e_temp.

-----------------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.F.  DISPOSICIÓN FINAL DE AIRE ACONDICIONADO.

WEIGHT OFF.

COMPUTE s101p51f_temp = s101p51f.
RECODE s101p51f_temp (7=SYSMIS).
VARIABLE LABELS s101p51f_temp "Disposición final de aire acondicionado".
VALUE LABELS s101p51f_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51f_temp DISPLAY=LABEL
  /TABLE s101p51f_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51f_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51f_temp.

------------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.G.  DISPOSICIÓN FINAL DE VENTILADOR.

WEIGHT OFF.

COMPUTE s101p51g_temp = s101p51g.
RECODE s101p51g_temp (7=SYSMIS).
VARIABLE LABELS s101p51g_temp "Disposición final de Ventilador".
VALUE LABELS s101p51g_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51g_temp DISPLAY=LABEL
  /TABLE s101p51g_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51g_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51g_temp.

----------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.H.  DISPOSICIÓN FINAL DE COCINA A GAS.

WEIGHT OFF.

COMPUTE s101p51h_temp = s101p51h.
RECODE s101p51h_temp (7=SYSMIS).
VARIABLE LABELS s101p51h_temp "Disposición final de cocina a gas".
VALUE LABELS s101p51h_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51h_temp DISPLAY=LABEL
  /TABLE s101p51h_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51h_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51h_temp.

----------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.I.  DISPOSICIÓN FINAL DE PLANCHA.

WEIGHT OFF.

COMPUTE s101p51i_temp = s101p51i.
RECODE s101p51i_temp (7=SYSMIS).
VARIABLE LABELS s101p51i_temp "Disposición final de plancha".
VALUE LABELS s101p51i_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51i_temp DISPLAY=LABEL
  /TABLE s101p51i_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51i_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51i_temp.

----------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.J.  DISPOSICIÓN FINAL DE TELÉFONO CELULAR 

WEIGHT OFF.

COMPUTE s101p51j_temp = s101p51j.
RECODE s101p51j_temp (7=SYSMIS).
VARIABLE LABELS s101p51j_temp "Disposición final de teléfono celular".
VALUE LABELS s101p51j_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51j_temp DISPLAY=LABEL
  /TABLE s101p51j_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51j_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51j_temp.

----------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 16.K.  DISPOSICIÓN FINAL DE RADIO 

WEIGHT OFF.

COMPUTE s101p51k_temp = s101p51k.
RECODE s101p51k_temp (7=SYSMIS).
VARIABLE LABELS s101p51k_temp "Disposición final de radio".
VALUE LABELS s101p51k_temp 1'Envió a un centro de acopio o depositó en un contenedor especial'
2'Vendió o regalo a un gestor informal / chatarrero'
3'Depositó con el resto de la basura común'
4'Quemó, enterró, botó, arrojó'
5'Almacenó en su hogar'
6'Entregó el aparato a una casa comercial o distribuidor'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s101p51k_temp DISPLAY=LABEL
  /TABLE s101p51k_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s101p51k_temp ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p51k_temp.

---------------------------------------------------------------------------------------------------------------------------------------.

* --- TABLA 17.  TIEMPO MODAL DE USO DE APARATOS ELÉCTRICOS/ELECTRÓNICOS ANTES DE CONVERTIRSE
* --- EN DESECHOS ELÉCTRICO (MODA en Años)

CTABLES
  /VLABELS VARIABLES=s101p52a s101p52b s101p52c s101p52d s101p52e s101p52f s101p52g s101p52h 
    s101p52i s101p52j s101p52k 
    DISPLAY=LABEL
  /TABLE s101p52a [S][MODE] + s101p52b [S][MODE] + s101p52c [S][MODE] + s101p52d [S][MODE] + 
    s101p52e [S][MODE] + s101p52f [S][MODE] + s101p52g [S][MODE] + s101p52h [S][MODE] + s101p52i 
    [S][MODE] + s101p52j [S][MODE] + s101p52k [S][MODE].

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 18.  PRÁCTICAS DE USO DE AGUA REALIZADAS POR LOS HOGARES.

WEIGHT OFF.

COMPUTE FILTRO_PAUA = (vi10 = 1 & vi10a = 1).

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=s101p61 s101p62 s101p63 s101p64 s101p65 NACIONAL FILTRO_PAUA DISPLAY=LABEL
  /TABLE s101p61 [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + s101p62 [C][COUNT F40.0, COLPCT.COUNT 
    PCT40.1] + s101p63 [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + s101p64 [C][COUNT F40.0, COLPCT.COUNT 
    PCT40.1] + s101p65 [C][COUNT F40.0, COLPCT.COUNT PCT40.1] BY NACIONAL [C] > FILTRO_PAUA [C]
  /CATEGORIES VARIABLES=s101p61 s101p62 s101p63 s101p64 s101p65 EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES= FILTRO_PAUA[1]  EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 19.  HOGARES QUE TIENEN DISPOSITIVOS DE AHORRO DE AGUA.

WEIGHT OFF.

COMPUTE P6_07_P6_08 = MIN(s101p67, s101p68).
VARIABLE LABELS P6_07_P6_08 "Habitualmente: Disponen de inodoro doble descarga / botella de agua dentro del tanque del inodoro".
VALUE LABELS P6_07_P6_08 1'Sí' 2'No' 3'No aplica'.
FREQUENCIES P6_07_P6_08.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=s101p66 P6_07_P6_08 NACIONAL FILTRO_PAUA DISPLAY=LABEL
  /TABLE s101p65 [C] + P6_07_P6_08 [C] BY NACIONAL [C] > FILTRO_PAUA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p65 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=P6_07_P6_08 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_PAUA [1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES FILTRO_PAUA P6_07_P6_08.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 20.  PRÁCTICAS DE USO DE ENERGÍA REALIZADAS POR LOS HOGARES.
* --- TABLA 20.A.  Desconectan los aparatos electrónicos y electrodomésticos cuando no los usan.

WEIGHT OFF.

COMPUTE FILTRO_ENERGIA = (vi12 = 1).

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=s101p71 NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p71 [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p71  [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 20.B.  Apagan los focos al salir de una habitación.

CTABLES
  /VLABELS VARIABLES=s101p72 NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p72 [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p72  [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 20.C. Evitan introducir alimentos calientes en el refrigerador.

RECODE s101p73 (1 = 2) (2 = 1) (ELSE = COPY) INTO s101p73r.

CTABLES
  /VLABELS VARIABLES=s101p73r NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p73r [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p73r [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES s101p73r.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 20.D. Planchan la mayor cantidad de ropa posible en una sola vez.

CTABLES
  /VLABELS VARIABLES=s101p74 NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p74 [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p74 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

*-----------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 20.E. Abren las cortinas y persianas para aprovechar la luz del sol.

CTABLES
  /VLABELS VARIABLES=s101p75 NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p75 [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p75 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 21.  HOGARES QUE TIENEN DISPOSITIVOS AHORRADORES DE ENERGÍA.

CTABLES
  /VLABELS VARIABLES=s101p76 NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p76 [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p76 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

CTABLES
  /VLABELS VARIABLES=s101p77 NACIONAL FILTRO_ENERGIA DISPLAY=LABEL
  /TABLE s101p77 [C] BY NACIONAL [C] > FILTRO_ENERGIA [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s101p77 [1, 2] EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=FILTRO_ENERGIA[1] EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE.

DELETE VARIABLES FILTRO_ENERGIA.

* --------------------------------------------------------------------------------------------------------------------------------------------------.
* D.  Cargar la base del Módulo Ambiental en Hogares ENEMDU (edición Octubre 2022) e inicialización de variables de desglose.
* NOTA: Se debe cerrar la anterior BDD del Módulo Ambiental en Hogares ENEMDU (edición Agosto 2022).

GET
  FILE='C:\Users\Lenovo\Documents\HOGARES 2022\BDD Publicadas\BDD_ENEMDU_2022_10\enemdu_ambiental_2022_10.sav'. 
DATASET NAME Ambientales WINDOW=FRONT. /* Esta base tiene 8864 registros.

*--- Generación de variables de desagregación.

COMPUTE NACIONAL=1.
VARIABLE LABELS NACIONAL "NACIONAL".
VALUE LABELS NACIONAL 1"Nacional".

COMPUTE prov = TRUNC(ciudad/10000).

VALUE LABELS prov 1'Azuay'
2'Bolívar'
3'Cañar'
4'Carchi'
5'Cotopaxi'
6'Chimborazo'
7'El Oro'
8'Esmeraldas'
9'Guayas'
10'Imbabura'
11'Loja'
12'Los Ríos'
13'Manabí'
14'Morona-Santiago'
15'Napo'
16'Pastaza'
17'Pichincha'
18'Tungurahua'
19'Zamora-Chinchipe'
20'Galápagos'
21'Sucumbíos'
22'Orellana'
23'Sto. Dgo de los Tsáchilas'
24'Santa Elena'
90'Zona No Delimitada'.

FREQUENCIES prov.

RECODE prov (1 thru 6, 10, 11, 17, 18 = 1) (7, 8, 9, 12, 13, 23, 24, 90 = 2) (14, 15, 16, 19, 21, 22 = 3) (20 = 4) INTO REG_NATURAL.
VARIABLE LABELS REG_NATURAL "Región Natural - DEAGA".
VALUE LABELS REG_NATURAL 1'Sierra' 2'Costa' 3'Amazonía' 4'Región Insular'.
FREQUENCIES REG_NATURAL.

SORT CASES BY id_hogar (A).

WEIGHT BY fexp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 22.  TIPOS DE BOLSAS UTILIZADAS POR LOS HOGARES PARA REALIZAR SUS COMPRAS.

CTABLES
  /VLABELS VARIABLES=s91p7 DISPLAY=LABEL
  /TABLE s91p7 [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s91p7 ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 23.  TIPOS DE BOLSAS UTILIZADAS POR LOS HOGARES PARA REALIZAR SUS COMPRAS POR REGIÓN.

CTABLES
  /VLABELS VARIABLES=REG_NATURAL s91p7 DISPLAY=LABEL
  /TABLE REG_NATURAL BY s91p7 [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=REG_NATURAL s91p7 ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 24.  CARACTERÍSTICAS DE INTERÉS AL COMPRAR NUEVOS PRODUCTOS.
* ---  TABLA 24.1  CARACTERÍSTICAS DE INTERÉS AL COMPRAR NUEVOS ALIMENTOS.

WEIGHT OFF.

COMPUTE s91p8a_temp = s91p8a.
RECODE s91p8a_temp  (5, 7=SYSMIS).
VARIABLE LABELS s91p8a_temp "Características de interés al comprar Nuevos Alimentos".
VALUE LABELS s91p8a_temp 1'El precio'
2'La marca'
3'El lugar de origen de los productos (productos locales)'
4'La etiqueta ecológica / garantía ecológica'
6'Productos orgánicos'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p8a_temp  DISPLAY=LABEL
  /TABLE s91p8a_temp  BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p8a_temp [1,2,3,4,6] EMPTY=INCLUDE.

DELETE VARIABLES s91p8a_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 24.2.  CARACTERÍSTICAS DE INTERÉS AL COMPRAR NUEVOS ELECTRODOMÉSTICOS.

WEIGHT OFF.

COMPUTE s91p8b_temp = s91p8b.
RECODE s91p8b_temp (6, 7=SYSMIS).
VARIABLE LABELS s91p8b_temp "Características de interés al comprar Nuevos Electrodomésticos".
VALUE LABELS s91p8b_temp 1'El precio'
2'La marca'
3'El lugar de origen de los productos (productos locales)'
4'La etiqueta ecológica / garantía ecológica'
5'El ahorro / consumo energético'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p8b_temp DISPLAY=LABEL
  /TABLE s91p8b_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p8b_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p8b_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 24.3.  CARACTERÍSTICAS DE INTERÉS AL COMPRAR NUEVOS PRODUCTOS ELECTRÓNICOS.

WEIGHT OFF.

COMPUTE s91p8c_temp = s91p8c.
RECODE s91p8c_temp (6, 7=SYSMIS).
VARIABLE LABELS s91p8c_temp "Características de interés al comprar Nuevos Productos Electrónicos".
VALUE LABELS s91p8c_temp 1'El precio'
2'La marca'
3'El lugar de origen de los productos (productos locales)'
4'La etiqueta ecológica / garantía ecológica'
5'El ahorro / consumo energético'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p8c_temp DISPLAY=LABEL
  /TABLE s91p8c_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p8c_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p8c_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.
* --- TABLA 24.4.  CARACTERÍSTICAS DE INTERÉS AL COMPRAR NUEVOS PRODUCTOS DE LIMPIEZA.

WEIGHT OFF.

COMPUTE s91p8d_temp = s91p8d.
RECODE s91p8d_temp (5, 6, 7=SYSMIS).
VARIABLE LABELS s91p8d_temp "Características de interés al comprar Nuevos Productos de Limpieza".
VALUE LABELS s91p8d_temp 1'El precio'
2'La marca'
3'El lugar de origen de los productos (productos locales)'
4'La etiqueta ecológica / garantía ecológica'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p8d_temp DISPLAY=LABEL
  /TABLE s91p8d_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p8d_temp [1,2,3,4] EMPTY=INCLUDE.

DELETE VARIABLES s91p8d_temp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 25. HOGARES QUE FUERON AFECTADOS AL MENOS POR UN PROBLEMA AMBIENTAL

WEIGHT OFF.

COMPUTE P25 = MIN(s91p91, s91p92, s91p93, s91p94, s91p95, s91p96). /* Esta variable señala a los hogares afectados al menos por un problema ambiental.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA P25 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY P25
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=P25 EMPTY=INCLUDE.

DELETE VARIABLES P25.

-------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 26. PROBLEMAS AMBIENTALES QUE AFECTAN A LOS BARRIOS.

CTABLES
  /VLABELS VARIABLES=s91p91 s91p92 s91p93 s91p94 s91p95 s91p96 Nacional area DISPLAY=LABEL
  /TABLE s91p91 [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + s91p92 [C][COUNT F40.0, COLPCT.COUNT 
    PCT40.1] + s91p93 [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + s91p94 [C][COUNT F40.0, COLPCT.COUNT 
    PCT40.1] + s91p95 [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + s91p96 [C][COUNT F40.0, COLPCT.COUNT 
    PCT40.1] BY Nacional [C] + area [C]
  /CATEGORIES VARIABLES=s91p91 s91p92 s91p93 s91p94 s91p95 s91p96 ORDER=A KEY=VALUE 
    EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=Nacional area ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 27. NIVEL DE PREOCUPACIÓN POR LA SITUACIÓN DEL AMBIENTE EN LOS BARRIOS

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s91p10 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] 
   BY s91p10
  /CATEGORIES VARIABLES=NACIONAL AREA  ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s91p10 EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 28. HOGARES QUE HAN PARTICIPADO EN AL MENOS UNA ACTIVIDAD AMBIENTAL EN LOS ÚLTIMOS 12 MESES.

WEIGHT OFF.

COMPUTE P28 = MIN(s91p111, s91p112, s91p113, s91p114, s91p115).
VARIABLE LABELS P28 "Hogares que han participado en al menos una actividad ambiental".
VALUE LABELS P28 1'Sí' 2'No'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA P28 DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [COUNT F40.0, ROWPCT.VALIDN PCT40.1] BY P28
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=P28 EMPTY=INCLUDE.

DELETE VARIABLES P28.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
*---TABLA 29.  ACTIVIDADES AMBIENTALES EN LOS QUE HAN PARTICIPADO LOS HOGARES.

CTABLES
  /VLABELS VARIABLES=s91p111 s91p112 s91p113 s91p114 s91p115 Nacional area DISPLAY=LABEL
  /TABLE s91p111 + s91p112 + s91p113 + s91p114 + s91p115 BY Nacional [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + 
    area [C][COUNT F40.0, COLPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s91p111, s91p112, s91p113, s91p114, s91p115 ORDER=A KEY=VALUE EMPTY=INCLUDE 
     TOTAL=YES POSITION=AFTER
  /CATEGORIES VARIABLES=Nacional area ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 30. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD AMBIENTAL.
* --- TABLA 30.1. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD DE LAS PERSONAS.

WEIGHT OFF.

COMPUTE s91p121_temp = s91p121.
RECODE s91p121_temp (99=SYSMIS).
VARIABLE LABELS s91p121_temp "Toda persona es responsable de la protección del medio ambiente".
VALUE LABELS s91p121_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p121_temp DISPLAY=LABEL
  /TABLE s91p121_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p121_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p121_temp.

* -----------------------------------------------------------------------------

* --- TABLA 30.2. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD AMBIENTAL DEL GOBIERNO.

WEIGHT OFF.

COMPUTE s91p122_temp = s91p122.
RECODE s91p122_temp (99=SYSMIS).
VARIABLE LABELS s91p122_temp "El gobierno es el principal responsable de la protección del medio ambiente".
VALUE LABELS s91p122_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p122_temp DISPLAY=LABEL
  /TABLE s91p122_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p122_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p122_temp.

* -----------------------------------------------------------------------------

* --- TABLA 30.3. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD AMBIENTAL DE LAS EMPRESAS.

WEIGHT OFF.

COMPUTE s91p123_temp = s91p123.
RECODE s91p123_temp (99=SYSMIS).
VARIABLE LABELS s91p123_temp "Las empresas son las principales responsables de reducir el deterioro del medio ambiente".
VALUE LABELS s91p123_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p123_temp DISPLAY=LABEL
  /TABLE s91p123_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p123_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p123_temp.

* -----------------------------------------------------------------------------

* --- TABLA 30.4. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD AMBIENTAL DE SÍ MISMOS.

WEIGHT OFF.

COMPUTE s91p124_temp = s91p124.
RECODE s91p124_temp (99=SYSMIS).
VARIABLE LABELS s91p124_temp "Mi hogar es responsable de reducir el deterioro del medio ambiente".
VALUE LABELS s91p124_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p124_temp DISPLAY=LABEL
  /TABLE s91p124_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p124_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p124_temp.

* -----------------------------------------------------------------------------

* --- TABLA 30.5. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD AMBIENTAL DE TODOS LOS HOGARES.

WEIGHT OFF.

COMPUTE s91p125_temp = s91p125.
RECODE s91p125_temp (99=SYSMIS).
VARIABLE LABELS s91p125_temp "Todos los hogares son responsables de reducir el deterioro del medio ambiente".
VALUE LABELS s91p125_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p125_temp DISPLAY=LABEL
  /TABLE s91p125_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p125_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p125_temp.

* -----------------------------------------------------------------------------

* --- TABLA 30.6. PERCEPCION DE LOS HOGARES SOBRE LA RESPONSABILIDAD AMBIENTAL INDIVIDUAL RELATIVA.

WEIGHT OFF.

COMPUTE s91p126_temp = s91p126.
RECODE s91p126_temp (99=SYSMIS).
VARIABLE LABELS s91p126_temp "No estoy dispuesto a cooperar para reducir el deterioro ambiental si los demás no hacen lo mismo".
VALUE LABELS s91p126_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p126_temp DISPLAY=LABEL
  /TABLE s91p126_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p126_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p126_temp.

* -----------------------------------------------------------------------------

* --- SECCIÓN 10: INFORMACIÓN AMBIENTAL (Jefe o Cónyuge)
* --- TABLA 31. PERCEPCION DE LOS HOGARES SOBRE LAS ACCIONES DE PROTECCIÓN DEL AMBIENTE.
* --- TABLA 31.1. PERCEPCION DE LOS HOGARES SOBRE EL COSTO DE LA VIDA CUANDO SE PROTEGE AL AMBIENTE.

WEIGHT OFF.

COMPUTE s91p131_temp = s91p131.
RECODE s91p131_temp (99=SYSMIS).
VARIABLE LABELS s91p131_temp "Proteger al ambiente encarece el costo de la vida".
VALUE LABELS s91p131_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p131_temp DISPLAY=LABEL
  /TABLE s91p131_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p131_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p131_temp.

* -----------------------------------------------------------------------------

* --- TABLA 31.2. PERCEPCION DE LOS HOGARES SOBRE EL AHORRO ECONOMICO EN EL HOGAR CUANDO SE PROTEGE AL AMBIENTE.

WEIGHT OFF.

COMPUTE s91p132_temp = s91p132.
RECODE s91p132_temp (99=SYSMIS).
VARIABLE LABELS s91p132_temp "Proteger al ambiente genera ahorros económicos para mi hogar".
VALUE LABELS s91p132_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p132_temp DISPLAY=LABEL
  /TABLE s91p132_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p132_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p132_temp.

* -----------------------------------------------------------------------------

* --- TABLA 31.3. PERCEPCION DE LOS HOGARES SOBRE LA INVERSION DE TIEMPO Y ESFUERZO CUANDO SE PROTEGE AL AMBIENTE.

WEIGHT OFF.

COMPUTE s91p133_temp = s91p133.
RECODE s91p133_temp (99=SYSMIS).
VARIABLE LABELS s91p133_temp "Proteger al ambiente requiere tiempo y esfuerzo".
VALUE LABELS s91p133_temp 1'Totalmente en desacuerdo'
2'Ligeramente en desacuerdo'
3'Ni de acuerdo ni en desacuerdo'
4'Ligeramente de acuerdo'
5'Totalmente de acuerdo'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL s91p133_temp DISPLAY=LABEL
  /TABLE s91p133_temp BY NACIONAL [COUNT F40.0, COLPCT.COUNT PCT40.2]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=INCLUDE
 /CATEGORIES VARIABLES=s91p133_temp [1,2,3,4,5] EMPTY=INCLUDE.

DELETE VARIABLES s91p133_temp.

 *-----------------------------------------------------------------------------

**********************************************************************************************************************************
**********************************************************************************************************************************.

* D. Cálculo de los tabulados de Personas.
* NOTA: Se debe abrir la BDD de Personas (edición Octubre 2022).
* Se debe cerrar la anterior BDD del Módulo Ambiental en Hogares ENEMDU (edición Octubre 2022).

GET
  FILE='C:\Users\Lenovo\Documents\HOGARES 2022\BDD Publicadas\BDD_ENEMDU_2022_10\enemdu_persona_2022_10.sav'. 
DATASET NAME Personas WINDOW=FRONT. /* Esta base tiene 29722 registros (uno por cada persona investigada).

*--- Generación de variables de desagregación.

COMPUTE NACIONAL=1.
COMPUTE Filtro_12 = (p03 >= 12).
COMPUTE Jefes = (p01 = '01').
VARIABLE LABELS NACIONAL "NACIONAL".
VALUE LABELS NACIONAL 1"Nacional".
VARIABLE LABELS Filtro_12 "Personas de 12+ años de edad".
VARIABLE LABELS Jefes "Jefes de hogar".
EXECUTE.

RECODE p03 (12 THRU 19 = 1) (20 THRU 30 = 2) (31 THRU 43 = 3) (44 THRU 58 = 4) (59 THRU 99 = 5) INTO Grupo_Edad_BICI.
VARIABLE LABELS Grupo_Edad_BICI "Grupos de edad para uso de bicicleta por personas".
VALUE LABELS Grupo_Edad_BICI 1'Grupo 12-19 años'
2'Grupo 20-30 años'
3'Grupo 31-43 años'
4'Grupo 44-58 años'
5'Grupo 59 años o más'.
FREQUENCIES Grupo_Edad_BICI.

SORT CASES BY id_persona (A).

WEIGHT BY fexp.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años o más).
* --- TABLA 32.  HOGARES EN LOS QUE AL MENOS UNA PERSONA UTILIZÓ BICICLETA.

WEIGHT OFF.

FILTER BY Filtro_12.

DATASET ACTIVATE Personas.
AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /PRESORTED
  /BREAK=id_hogar
  /s5p1a_min 'Hogares donde al menos una persona usa bicicleta'=MIN(s5p1a).

VALUE LABELS s5p1a_min 1'Sí' 2'No'.

FILTER BY Jefes.
WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s5p1a_min DISPLAY=LABEL
  /TABLE NACIONAL + AREA BY s5p1a_min [COUNT F40.0, ROWPCT.VALIDN PCT40.1]
  /CATEGORIES VARIABLES=NACIONAL AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s5p1a_min ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años o más).
* --- TABLA 33. USO DE BICICLETA POR PERSONA.

FILTER BY Filtro_12.

CTABLES
  /VLABELS VARIABLES=NACIONAL Grupo_Edad_BICI s5p1a DISPLAY=LABEL
  /TABLE NACIONAL [COUNT F40.0, ROWPCT.VALIDN PCT40.1] + Grupo_Edad_BICI [C][COUNT F40.0, 
    ROWPCT.VALIDN PCT40.1] BY s5p1a [C]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Grupo_Edad_BICI ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s5p1a ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años y más)
* --- TABLA 34.  POBLACIÓN QUE UTILIZÓ BICICLETAS POR GRUPO DE EDAD.

CTABLES
  /VLABELS VARIABLES=NACIONAL Grupo_Edad_BICI s5p1a DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, COLPCT.COUNT PCT40.1] + Grupo_Edad_BICI [C][COUNT F40.0, COLPCT.COUNT PCT40.1] BY s5p1a [C]
  /CATEGORIES VARIABLES=NACIONAL Grupo_Edad_BICI ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s5p1a [1] EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años y más)
* --- TABLA 35.  FRECUENCIA DEL USO DE BICICLETAS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s5p1b DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] BY s5p1b [C]
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=AREA  ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s5p1b ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES POSITION=AFTER.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años y más)
* --- TABLA 36.  MEDIO DE TRASLADO DE LAS PERSONAS DE 12+ AÑOS A NIVEL NACIONAL.

WEIGHT OFF.

RECODE s5p2 (5,6 = 1) (1 THRU 4 = 2) (7 = 3) (8 = 4) (10 = 5) (99 = 6) (9 = 7) INTO MEDIO_TRASLADO.
VARIABLE LABELS MEDIO_TRASLADO "Medio de traslado de las personas de 12 años y más".
VALUE LABELS MEDIO_TRASLADO 1'Vehículo particular'
2'Transporte público'
3'Bicicleta'
4'Caminar'
5'Otro'
6'No aplica'
7'Vehículo eléctrico'.

WEIGHT BY fexp.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA  MEDIO_TRASLADO DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] BY MEDIO_TRASLADO [C]
  /CATEGORIES VARIABLES=NACIONAL MEDIO_TRASLADO ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=AREA ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años y más)
* --- TABLA 37. USO DEL TRANSPORTE PÚBLICO COMO MEDIO PRINCIPAL DE TRASLADO DE LAS PERSONAS DE 12+ AÑOS.

CTABLES
  /VLABELS VARIABLES=NACIONAL AREA s5p2 DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + AREA [C][COUNT F40.0, ROWPCT.VALIDN 
    PCT40.1] BY s5p2
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=AREA ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=s5p2 [1, 2, 3, 4] EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años y más)
* --- TABLA 38.  RAZONES PRINCIPALES PARA MOVILIZARSE POR TODOS LOS MEDIOS DE TRASLADO.

CTABLES
  /VLABELS VARIABLES=s5p3 NACIONAL area DISPLAY=LABEL
  /TABLE s5p3 [C] BY NACIONAL [C][COUNT F40.0, ROWPCT.COUNT PCT40.1] + area [C][COUNT F40.0, 
    ROWPCT.COUNT PCT40.1]
  /CATEGORIES VARIABLES=s5p3 NACIONAL area ORDER=A KEY=VALUE EMPTY=INCLUDE.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

* --- SECCIÓN 6: INFORMACIÓN AMBIENTAL (Personas de 12 años y más)
* --- TABLA 39.  MOVILIDAD DE LA POBLACIÓN POR GRUPO DE EDAD.

CTABLES
  /VLABELS VARIABLES=NACIONAL Grupo_Edad_BICI MEDIO_TRASLADO DISPLAY=LABEL
  /TABLE NACIONAL [C][COUNT F40.0, ROWPCT.VALIDN PCT40.1] + Grupo_Edad_BICI [C][COUNT F40.0, 
    ROWPCT.VALIDN  PCT40.1] BY MEDIO_TRASLADO
  /CATEGORIES VARIABLES=NACIONAL ORDER=A KEY=VALUE EMPTY=EXCLUDE
  /CATEGORIES VARIABLES=Grupo_Edad_BICI ORDER=A KEY=VALUE EMPTY=INCLUDE
  /CATEGORIES VARIABLES=MEDIO_TRASLADO EMPTY=INCLUDE TOTAL=YES.

* --------------------------------------------------------------------------------------------------------------------------------------------------.

WEIGHT OFF.
FILTER OFF.
USE ALL.

******************************************************************************************************************
* FIN DE LA SINTAXIS DE TABULADOS MÓDULO AMBIENTAL DE HOGARES - ENEMDU 2022.
******************************************************************************************************************.




